==> haskell-prettyprinter-convert-ansi-wl-pprint-1.1.2-216-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-convert-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-convert-ansi-wl-pprint
version:              1.1.2
visibility:           public
id:
    prettyprinter-convert-ansi-wl-pprint-1.1.2-EExCgKwurqHBosFUKxpnmp

key:
    prettyprinter-convert-ansi-wl-pprint-1.1.2-EExCgKwurqHBosFUKxpnmp

license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:
    Converter from »ansi-wl-pprint« documents to »prettyprinter«-based ones.

description:          See README.md
category:             User Interfaces, Text
abi:                  14618592e078f399485bd9bf3b696eac
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Convert.AnsiWlPprint
    Prettyprinter.Convert.AnsiWlPprint

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-convert-ansi-wl-pprint-1.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-convert-ansi-wl-pprint-1.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-convert-ansi-wl-pprint-1.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-convert-ansi-wl-pprint
hs-libraries:
    HSprettyprinter-convert-ansi-wl-pprint-1.1.2-EExCgKwurqHBosFUKxpnmp

depends:
    ansi-terminal-1.0.2-D46JaHr1BfPBLAK7nuv4I
    ansi-wl-pprint-0.6.9-B3Lar7FqiubAcDnIzFLvDA base-4.17.2.1
    prettyprinter-1.7.1-2SyS45w2YIjHD6NDr8Zx1B
    prettyprinter-ansi-terminal-1.1.3-1dwjtSDumlJADFnP6ZWFZ text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html/prettyprinter-convert-ansi-wl-pprint.haddock

haddock-html:
    /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-convert-ansi-wl-pprint-1.1.2-219-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-convert-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-convert-ansi-wl-pprint
version:              1.1.2
visibility:           public
id:
    prettyprinter-convert-ansi-wl-pprint-1.1.2-Hh6EIvk9IlM1CrXhIHyNZL

key:
    prettyprinter-convert-ansi-wl-pprint-1.1.2-Hh6EIvk9IlM1CrXhIHyNZL

license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:
    Converter from »ansi-wl-pprint« documents to »prettyprinter«-based ones.

description:          See README.md
category:             User Interfaces, Text
abi:                  a702b1b79fb763e23f322ef774aef170
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Convert.AnsiWlPprint
    Prettyprinter.Convert.AnsiWlPprint

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-convert-ansi-wl-pprint-1.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-convert-ansi-wl-pprint-1.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-convert-ansi-wl-pprint-1.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-convert-ansi-wl-pprint
hs-libraries:
    HSprettyprinter-convert-ansi-wl-pprint-1.1.2-Hh6EIvk9IlM1CrXhIHyNZL

depends:
    ansi-terminal-1.0.2-6TxOAUbfOQrDbPnWIRhRhS
    ansi-wl-pprint-0.6.9-HkA3GfftKZN6uSmrRbFaJm base-4.17.2.1
    prettyprinter-1.7.1-L5f5fQ72tN6KrwJu1IwhTZ
    prettyprinter-ansi-terminal-1.1.3-3gezl4y1Fis6b0vPmlsQhT text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html/prettyprinter-convert-ansi-wl-pprint.haddock

haddock-html:
    /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
